CreatePhoneMultiFactorInfoRequest class

Represents a phone specific user-enrolled second factor for a Auth.createUser call.

Inheritance

Constructors

CreatePhoneMultiFactorInfoRequest({String? displayName, required String phoneNumber})

Properties

displayName → String?
The optional display name for an enrolled second factor.
finalinherited
factorId → String
The type identifier of the second factor.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String
The phone number associated with a phone second factor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited