MultiFactorInfo class abstract

Represents the common properties of a user-enrolled second factor.

Implementers

Constructors

MultiFactorInfo.fromJson(Map<String, dynamic> map)
factory

Properties

displayName → String?
The optional display name of the enrolled second factor.
no setter
enrollmentTime → DateTime?
The optional date the second factor was enrolled.
no setter
factorId → String
The type identifier of the second factor.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String
The ID of the enrolled second factor. This ID is unique to the user.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
Returns the JSON representation of the snapshot
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited