TenantAwareAuth class
Auth service bound to the provided app and tenant.
Properties
Methods
-
createCustomToken(
String uid, [Map< String, dynamic> developerClaims = const {}]) → Future<String> -
Creates a new Firebase custom token (JWT) that can be sent back to a client
device to use to sign in with the client SDKs' signInWithCustomToken()
methods.
inherited
-
createUser(
{bool? disabled, String? displayName, String? email, bool? emailVerified, String? password, String? phoneNumber, Uri? photoUrl, String? uid, List< CreateMultiFactorInfoRequest> ? multiFactorEnrolledFactors}) → Future<UserRecord> -
Creates a new user.
inherited
-
delete(
) → Future< void> -
inherited
-
deleteUser(
String uid) → Future< void> -
Deletes an existing user.
inherited
-
generateEmailVerificationLink(
String email, [ActionCodeSettings? actionCodeSettings]) → Future< String> -
Generates the out of band email action link for email verification flows
for the email specified using the action code settings provided.
inherited
-
generatePasswordResetLink(
String email, [ActionCodeSettings? actionCodeSettings]) → Future< String> -
Generates the out of band email action link for password reset flows for
the email specified using the action code settings provided.
inherited
-
generateSignInWithEmailLink(
String email, ActionCodeSettings? actionCodeSettings) → Future< String> -
Generates the out of band email action link for email link sign-in flows
for the email specified using the action code settings provided.
inherited
-
getUser(
String uid) → Future< UserRecord> -
Gets the user data for the user corresponding to a given
uid.inherited -
getUserByEmail(
String email) → Future< UserRecord> -
Looks up the user identified by the provided email and returns a future
that is fulfilled with a user record for the given user if that user is
found.
inherited
-
getUserByPhoneNumber(
String phoneNumber) → Future< UserRecord> -
Looks up the user identified by the provided phone number and returns a
future that is fulfilled with a user record for the given user if that
user is found.
inherited
-
listUsers(
[int? maxResults, String? pageToken]) → Future< ListUsersResult> -
Retrieves a list of users (single batch only) with a size of
maxResultsand starting from the offset as specified bypageToken.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revokeRefreshTokens(
String uid) → Future< void> -
Revokes all refresh tokens for an existing user.
inherited
-
setCustomUserClaims(
String uid, Map< String, dynamic> customUserClaims) → Future<void> -
Sets additional developer claims on an existing user identified by the
provided uid, typically used to define user roles and levels of access.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateUser(
String uid, {bool? disabled, String? displayName, String? email, bool? emailVerified, String? password, String? phoneNumber, Uri? photoUrl, List< UpdateMultiFactorInfoRequest> ? multiFactorEnrolledFactors}) → Future<UserRecord> -
Updates an existing user.
inherited
-
verifyIdToken(
String idToken, [bool checkRevoked = false]) → Future< IdToken> -
Verifies a Firebase ID token (JWT).
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited